package javax.swing.plaf.basic;

import java.awt.Dimension;
import javax.swing.plaf.UIResource;
import java.awt.Graphics;
import javax.swing.UIManager;
import java.awt.Color;
import javax.swing.SwingConstants;
import javax.swing.JButton;

public class BasicArrowButton extends JButton implements SwingConstants
{
    protected int direction;
    private Color shadow;
    private Color darkShadow;
    private Color highlight;
    
    public BasicArrowButton(int direction, Color background, Color shadow, Color darkShadow, Color highlight) {
        this.setRequestFocusEnabled(false);
        this.setDirection(direction);
        this.setBackground(background);
        this.shadow = shadow;
        this.darkShadow = darkShadow;
        this.highlight = highlight;
    }
    
    public BasicArrowButton(int n) {
        this(n, UIManager.getColor("control"), UIManager.getColor("controlShadow"), UIManager.getColor("controlDkShadow"), UIManager.getColor("controlLtHighlight"));
    }
    
    public int getDirection() {
        return this.direction;
    }
    
    public void setDirection(int direction) {
        this.direction = direction;
    }
    
    @Override
    public void paint(Graphics g) {
        int width = this.getSize().width;
        int height = this.getSize().height;
        Color color = g.getColor();
        int pressed = this.getModel().isPressed();
        int enabled = this.isEnabled();
        g.setColor(this.getBackground());
        g.fillRect(1, 1, width - 2, height - 2);
        if (this.getBorder() != null && !(this.getBorder() instanceof UIResource)) {
            this.paintBorder(g);
        }
        else if (!(pressed == 0)) {
            g.setColor(this.shadow);
            g.drawRect(0, 0, width - 1, height - 1);
        }
        else {
            g.drawLine(0, 0, 0, height - 1);
            g.drawLine(1, 0, width - 2, 0);
            g.setColor(this.highlight);
            g.drawLine(1, 1, 1, height - 3);
            g.drawLine(2, 1, width - 3, 1);
            g.setColor(this.shadow);
            g.drawLine(1, height - 2, width - 2, height - 2);
            g.drawLine(width - 2, 1, width - 2, height - 3);
            g.setColor(this.darkShadow);
            g.drawLine(0, height - 1, width - 1, height - 1);
            g.drawLine(width - 1, height - 1, width - 1, 0);
        }
        if (height < 5 || width < 5) {
            g.setColor(color);
            return;
        }
        if (!(pressed == 0)) {
            g.translate(1, 1);
        }
        int max = Math.max(Math.min((height - 4) / 3, (width - 4) / 3), 2);
        this.paintTriangle(g, (width - max) / 2, (height - max) / 2, max, this.direction, (boolean)enabled);
        if (!(pressed == 0)) {
            g.translate(-1, -1);
        }
        g.setColor(color);
        return;
    }
    
    @Override
    public Dimension getPreferredSize() {
        return new Dimension(16, 16);
    }
    
    @Override
    public Dimension getMinimumSize() {
        return new Dimension(5, 5);
    }
    
    @Override
    public Dimension getMaximumSize() {
        return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
    }
    
    @Override
    public boolean isFocusTraversable() {
        return false;
    }
    
    public void paintTriangle(Graphics graphics, int n, int n2, int max, int n3, boolean b) {
        Color color = graphics.getColor();
        int n4 = 0;
        max = Math.max(max, 2);
        int n5 = max / 2 - 1;
        graphics.translate(n, n2);
        if (b) {
            graphics.setColor(this.darkShadow);
        }
        else {
            graphics.setColor(this.shadow);
        }
        switch (n3) {
            case 1: {
                int i;
                for (i = 0; i < max; ++i) {
                    graphics.drawLine(n5 - i, i, n5 + i, i);
                }
                if (!b) {
                    graphics.setColor(this.highlight);
                    graphics.drawLine(n5 - i + 2, i, n5 + i, i);
                    break;
                }
                break;
            }
            case 5: {
                if (!b) {
                    graphics.translate(1, 1);
                    graphics.setColor(this.highlight);
                    for (int j = max - 1; j >= 0; ++n4, --j) {
                        graphics.drawLine(n5 - j, n4, n5 + j, n4);
                    }
                    graphics.translate(-1, -1);
                    graphics.setColor(this.shadow);
                }
                for (int n6 = 0, k = max - 1; k >= 0; ++n6, --k) {
                    graphics.drawLine(n5 - k, n6, n5 + k, n6);
                }
                break;
            }
            case 7: {
                int l;
                for (l = 0; l < max; ++l) {
                    graphics.drawLine(l, n5 - l, l, n5 + l);
                }
                if (!b) {
                    graphics.setColor(this.highlight);
                    graphics.drawLine(l, n5 - l + 2, l, n5 + l);
                    break;
                }
                break;
            }
            case 3: {
                if (!b) {
                    graphics.translate(1, 1);
                    graphics.setColor(this.highlight);
                    for (int n7 = max - 1; n7 >= 0; ++n4, --n7) {
                        graphics.drawLine(n4, n5 - n7, n4, n5 + n7);
                    }
                    graphics.translate(-1, -1);
                    graphics.setColor(this.shadow);
                }
                for (int n8 = 0, n9 = max - 1; n9 >= 0; ++n8, --n9) {
                    graphics.drawLine(n8, n5 - n9, n8, n5 + n9);
                }
                break;
            }
        }
        graphics.translate(-n, -n2);
        graphics.setColor(color);
    }
}
